=============================
Python Lunar
=============================

.. |license| image:: https://img.shields.io/pypi/l/pylunar.svg
   :target: http://opensource.org/licenses/BSD
   :alt: BSD License

.. |version| image:: http://img.shields.io/pypi/v/pylunar.svg
   :target: https://pypi.python.org/pypi/pylunar
   :alt: Software Version

.. |github| image:: https://github.com/mareuter/pylunar/actions/workflows/ci.yaml/badge.svg
  :target: https://github.com/mareuter/pylunar
  :alt: Github build status

.. |python| image:: https://img.shields.io/pypi/pyversions/pylunar.svg
  :target: https://pypi.python.org/pypi/pylunar
  :alt: Supported Python

.. |docs| image:: https://readthedocs.org/projects/pylunar/badge/?version=latest
  :target: https://pylunar.readthedocs.io
  :alt: Readthedocs status

.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit
  :target: https://github.com/pre-commit/pre-commit
  :alt: Uses pre-commit

|license| |python| |version| |github| |docs| |pre-commit|

Information for completing the Astronomical League's Lunar and Lunar II observing programs. Uses the `pyephem <https://rhodesmill.org/pyephem>`_ package to calculate lunar information.


Features
--------

* Offer moon information based on location and date/time.
* Offer lunar targets for AL observing clubs based on terminator location.

